==> haskell-hls-plugin-api-2.0.0.0-12-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-plugin-api.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-plugin-api
version:              2.0.0.0
visibility:           public
id:                   hls-plugin-api-2.0.0.0-Ei7P6RE464bGLnm9IUdFJ
key:                  hls-plugin-api-2.0.0.0-Ei7P6RE464bGLnm9IUdFJ
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:             Haskell Language Server API for plugin communication
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  1bcfd41542cf0844f5d5277810e31c79
exposed:              True
exposed-modules:
    Ide.Plugin.Config Ide.Plugin.ConfigUtils Ide.Plugin.Properties
    Ide.Plugin.RangeMap Ide.PluginUtils Ide.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-plugin-api-2.0.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-plugin-api-2.0.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-plugin-api-2.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-plugin-api
hs-libraries:         HShls-plugin-api-2.0.0.0-Ei7P6RE464bGLnm9IUdFJ
depends:
    Diff-0.4.1-BOxCLpHEbnv464iV7Wt9tY
    aeson-2.1.2.1-25ntyCXNIMdHgIjcbgcdOM base-4.17.2.1 containers-0.6.7
    data-default-0.7.1.1-HuI8bY4bNR4F11jcRg6vOi
    dependent-map-0.4.0.0-8zknUYGZrMF8F060ezLWbG
    dependent-sum-0.7.2.0-9a4Y5ZbC1JeIBgMkafjjB2
    dlist-1.0-I6FB5Nlk17hG16fxQzZSEb
    extra-1.7.16-9yFW5HMy3QJKMvZBMWGOPz filepath-1.4.2.2 ghc-9.4.8
    hashable-1.4.4.0-3P57kjJkCag7O0bwYoaxX1
    hls-graph-2.0.0.0-1UsjfppDjxI4IuI0TD5Vaa
    hw-fingertree-0.1.2.1-E9vdtZhns255euBpqmtSnq
    lens-5.2.3-9B9P7XM4qGB6Xd7Di9aRFA
    lens-aeson-1.2.3-1lTKci8Zbtx83P0a0xfX7P
    lsp-1.6.0.0-JssQdMMkdnV6Y1aZJgkn3p
    megaparsec-9.6.1-K6n3nDiAbysFzcr1mYtRG7
    opentelemetry-0.8.0-BeMORCTdDZmEKBbVijqZ2R
    optparse-applicative-0.17.1.0-3m15PZJ9R8tLZfnW85Yn0z
    regex-tdfa-1.3.2.2-LOCZw2rru5CARfqoQF4uzE text-2.0.2
    transformers-0.5.6.2 unix-2.7.3
    unordered-containers-0.2.20-2oScjwZejU42oDENjBi2vG

haddock-interfaces:
    /usr/share/doc/haskell-hls-plugin-api/html/hls-plugin-api.haddock

haddock-html:         /usr/share/doc/haskell-hls-plugin-api/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-plugin-api-2.0.0.0-13-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-plugin-api.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-plugin-api
version:              2.0.0.0
visibility:           public
id:                   hls-plugin-api-2.0.0.0-81BySD4vqkK8F619Geablm
key:                  hls-plugin-api-2.0.0.0-81BySD4vqkK8F619Geablm
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:             Haskell Language Server API for plugin communication
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  640584e8699428ea2213ca3f60ccccd3
exposed:              True
exposed-modules:
    Ide.Plugin.Config Ide.Plugin.ConfigUtils Ide.Plugin.Properties
    Ide.Plugin.RangeMap Ide.PluginUtils Ide.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-plugin-api-2.0.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-plugin-api-2.0.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-plugin-api-2.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-plugin-api
hs-libraries:         HShls-plugin-api-2.0.0.0-81BySD4vqkK8F619Geablm
depends:
    Diff-0.4.1-BOxCLpHEbnv464iV7Wt9tY
    aeson-2.1.2.1-25ntyCXNIMdHgIjcbgcdOM base-4.17.2.1 containers-0.6.7
    data-default-0.7.1.1-HuI8bY4bNR4F11jcRg6vOi
    dependent-map-0.4.0.0-8zknUYGZrMF8F060ezLWbG
    dependent-sum-0.7.2.0-9a4Y5ZbC1JeIBgMkafjjB2
    dlist-1.0-I6FB5Nlk17hG16fxQzZSEb
    extra-1.7.16-9yFW5HMy3QJKMvZBMWGOPz filepath-1.4.2.2 ghc-9.4.8
    hashable-1.4.4.0-3P57kjJkCag7O0bwYoaxX1
    hls-graph-2.0.0.0-K5RL1HYdiga4ZnyILR6U72
    hw-fingertree-0.1.2.1-E9vdtZhns255euBpqmtSnq
    lens-5.2.3-9B9P7XM4qGB6Xd7Di9aRFA
    lens-aeson-1.2.3-1lTKci8Zbtx83P0a0xfX7P
    lsp-1.6.0.0-JssQdMMkdnV6Y1aZJgkn3p
    megaparsec-9.6.1-K6n3nDiAbysFzcr1mYtRG7
    opentelemetry-0.8.0-BeMORCTdDZmEKBbVijqZ2R
    optparse-applicative-0.17.1.0-3m15PZJ9R8tLZfnW85Yn0z
    regex-tdfa-1.3.2.2-LOCZw2rru5CARfqoQF4uzE text-2.0.2
    transformers-0.5.6.2 unix-2.7.3
    unordered-containers-0.2.20-2oScjwZejU42oDENjBi2vG

haddock-interfaces:
    /usr/share/doc/haskell-hls-plugin-api/html/hls-plugin-api.haddock

haddock-html:         /usr/share/doc/haskell-hls-plugin-api/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
